<?php
/**
 * Blackbird MenuManager Module
 *
 * NOTICE OF LICENSE
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to contact@bird.eu so we can send you a copy immediately.
 *
 * @group            Blackbird
 * @package		Blackbird_MenuManager
 * @copyright           Copyright (c) 2016 Blackbird (http://black.bird.eu)
 * @author		Blackbird Team
 */
namespace Blackbird\MenuManager\Block\NodeType;

use Blackbird\MenuManager\Api\Data\NodeInterface;
use Magento\Backend\Block\Template\Context;
use Magento\Backend\Block\Template;
use Magento\Framework\App\ResourceConnection;
use Magento\Framework\Profiler;
use Blackbird\MenuManager\Api\NodeTypeInterfaceFront;

class Group extends AbstractNodeTypeFront implements NodeInterface
{
    protected $nodes;
    protected $groupUrls;
    /**
     * @var ResourceConnection
     */
    private $connection;

    /**
     * @var Profiler
     */
    private $profiler;

    public function __construct(
        Context $context,
        ResourceConnection $connection,
        Profiler $profiler,
        $data = []
    ) {
        $this->connection = $connection;
        $this->profiler = $profiler;
        parent::__construct($context, $data);
    }


    public function fetchData(array $nodes)
    {
        $this->profiler->start(__METHOD__);
        $localNodes = [];
        $groupIds = [];
        foreach ($nodes as $node) {
            $localNodes[$node->getId()] = $node;
            $groupIds[] = (int)$node->getContent();
        }
        $this->nodes = $localNodes;
        $table = $this->connection->getTableName('url_rewrite');
        $select = $this->connection->getConnection('read')
            ->select()
            ->from($table, ['entity_id', 'request_path'])
            ->where('entity_type = ?', 'group')
            ->where('store_id = ?', $this->_storeManager->getStore()->getId())
            ->where('entity_id IN (' . implode(',', $groupIds) . ')');
        $this->groupUrls = $this->connection->getConnection('read')->fetchPairs($select);
        $this->profiler->stop(__METHOD__);
    }

    /**
     * define the url of the node
     *
     * @param $node
     * @param $childrenArray
     * @return string
     */
    public function getUrlNode($node, $childrenArray)
    {
        $url = '';
       if($childrenArray && $node->getLinkFirstChild()){
           $url = $childrenArray[0]->getUrlPath();
           $this->setUrl($url);
           $this->setLinkFirstChild(1);
       }
       return $url;
    }

    /**
     * @param $nodeId
     * @param $level
     * @param $classes
     * @param $childrenHtml
     * @param $childrenArray
     * @return string
     */
    public function getHtml($nodeId, $level, $classes, $childrenHtml, $childrenArray)
    {
        $node = $this->nodes[$nodeId];

        $node->setUrlPath($this->getUrlNode($node, $childrenArray));

        $url = $this->getData('url');
        $classes = $this->getIsActiveClass($url, $node, $classes, $childrenArray);

        return parent::getHtml($nodeId, $level, $classes, $childrenHtml, $childrenArray);
    }
}
